Welcome to UltraNest's documentation!
======================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   readme
   installation
   method
   using-ultranest.ipynb
   priors.ipynb
   performance
   API
   issues
   contributing
   history

.. toctree::
   :maxdepth: 1
   :caption: Tutorials:

   example-sine-line.ipynb
   example-sine-modelcomparison.ipynb
   example-sine-highd.ipynb
   example-intrinsic-distribution.ipynb
   example-line.ipynb
   example-outliers.ipynb
   example-sine-bayesian-workflow.ipynb
   example-warmstart.ipynb
   debugging.ipynb

.. include:: ../README.rst

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
